@@ -13,8 +13,8 @@
 
 namespace bt
 {
-/**
-@author Joris Guisson
+/*!
+\author Joris Guisson
 */
 class KTORRENT_EXPORT Timer
 {
